/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* MASTER: Data Preparation (00_preparation.do), executed by _PROJECT_MASTER_.do 
* 
* This file is the master file for the preparation of the SHARE data. 
* It prepares data from the first and second wave of SHARE (release 2.5.0).
* For documentation and data access, visit: http://www.share-project.org/ 
*
* Data preparation consists of six steps implemented in different do-files:
* 	0) prepare household-level data
*	1) prepare respondent-level data
*	2) prepare data on children (reported by the so-called family respondent)
*	3) prepare data on grandparenting (looking after grandchildren in the absence of parents) 
*	4) prepare couple-level data
*	5) create a dyadic dataset of couple-child dyads 
*
* All of these steps are executed separately for each wave. 
* To keep track of this, we generate wave-specific temporary data files. 
* Wave-specific data are later combined (see 10_sample.do).
*
***********************************************************************/

run config
set more off

log using "${logDir}/dataselection.smcl", smcl replace name(dataselection)
log off dataselection

*********************************
* 00-0 Prepare household data
*      (see 00-0_households.do)
*********************************
do 00-0_households

*********************************
* 00-1 Prepare basic respondent level data
*      (see 00-1_respondents.do)
*********************************
do 00-1_respondents

*********************************
* 00-2 Prepare children data
*      (see 00-2_children.do)
*********************************
do 00-2_children

*********************************
* 00-3 Prepare grandparenting data
*      (see 00-3_grandparenting.do)
*********************************
do 00-3_grandparenting

*********************************
* 00-4 Prepare couple data structure
*      (see 00-4_couples.do)
*********************************
do 00-4_couples

*********************************
* 00-5 Prepare couple-child dyad data 
*      structure
*      (see 00-5_couple-child-dyads.do)
*********************************
do 00-5_couple-child-dyads

capt log off dataselection
capt log close dataselection
clear
exit

