/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
* 
* PROJECT MASTER FILE
*
* The code the empirical analysis is divided into different sub-files, each of which
* completes a specific step in the analysis. 
  
* This master file keeps calls each of these steps in the right order. 
* You can run the complete analysis by executing this file.
*
* There are four steps:
* 0) Preparation of the original data
* 1) Selection of sample
* 2) Imputation of missing values
* 3) Statistical analyses   
* 
* Detailed documentation can be found in the respective sub-files. 
*
***********************************************************************/

run config 	// call the configuration file (specifies all settings)

*********************************
* 00 - prepare data
* 	   (households, respondents, children, 
*       grandparenting, couples, 
*       couple-child dyads; all wave-
*       specific)
*********************************
do 00_preparation.do

*********************************
* 10 - select the sample
*      (combine wave data on dyads,
*       select couples and dyads)
*********************************
do 10_sample.do

*********************************
* 20 - generate the dependent 
*      variable
*      (impute missing care hours; 
*       generate grandfather's share)
*********************************
do 20_variables_imputation.do 

*********************************
* 30 - analyze the data
*      (descriptives, regression 
*       models, additional analyses)
*********************************
do 30_analysis.do

clear
exit


